@@ -31,6 +31,7 @@ typedef void (*ArvFrameCallback)	(ArvBuffer *buffer);
 
 /**
  * ArvBufferStatus:
+ * @ARV_BUFFER_STATUS_UNKNOWN: unknown status
  * @ARV_BUFFER_STATUS_SUCCESS: the buffer contains a valid image
  * @ARV_BUFFER_STATUS_CLEARED: the buffer is cleared
  * @ARV_BUFFER_STATUS_TIMEOUT: timeout was reached before all packets are received
@@ -42,7 +43,8 @@ typedef void (*ArvFrameCallback)	(ArvBuffer *buffer);
  */
 
 typedef enum {
-	ARV_BUFFER_STATUS_SUCCESS,
+	ARV_BUFFER_STATUS_UNKNOWN = -1,
+	ARV_BUFFER_STATUS_SUCCESS = 0,
 	ARV_BUFFER_STATUS_CLEARED,
 	ARV_BUFFER_STATUS_TIMEOUT,
 	ARV_BUFFER_STATUS_MISSING_PACKETS,
@@ -52,6 +54,33 @@ typedef enum {
 	ARV_BUFFER_STATUS_ABORTED
 } ArvBufferStatus;
 
+/**
+ * ArvBufferPayloadType:
+ * @ARV_BUFFER_PAYLOAD_TYPE_UNKNOWN: unknown payload type
+ * @ARV_BUFFER_PAYLOAD_TYPE_IMAGE: image data
+ * @ARV_BUFFER_PAYLOAD_TYPE_RAWDATA: raw data
+ * @ARV_BUFFER_PAYLOAD_TYPE_FILE: file
+ * @ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA: chunk data
+ * @ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA: extended chunk data
+ * @ARV_BUFFER_PAYLOAD_TYPE_JPEG: JPEG data
+ * @ARV_BUFFER_PAYLOAD_TYPE_JPEG2000: JPEG2000 data
+ * @ARV_BUFFER_PAYLOAD_TYPE_H264: h264 data
+ * @ARV_BUFFER_PAYLOAD_TYPE_MULTIZONE_IMAGE: multizone image
+*/
+
+typedef enum {
+	ARV_BUFFER_PAYLOAD_TYPE_UNKNOWN = 		-1,
+	ARV_BUFFER_PAYLOAD_TYPE_IMAGE =			0x0001,
+	ARV_BUFFER_PAYLOAD_TYPE_RAWDATA = 		0x0002,
+	ARV_BUFFER_PAYLOAD_TYPE_FILE = 			0x0003,
+	ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA = 		0x0004,
+	ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA = 	0x0005, /* Deprecated */
+	ARV_BUFFER_PAYLOAD_TYPE_JPEG = 			0x0006,
+	ARV_BUFFER_PAYLOAD_TYPE_JPEG2000 = 		0x0007,
+	ARV_BUFFER_PAYLOAD_TYPE_H264 = 			0x0008,
+	ARV_BUFFER_PAYLOAD_TYPE_MULTIZONE_IMAGE = 	0x0009
+} ArvBufferPayloadType;
+
 #define ARV_TYPE_BUFFER             (arv_buffer_get_type ())
 #define ARV_BUFFER(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), ARV_TYPE_BUFFER, ArvBuffer))
 #define ARV_BUFFER_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), ARV_TYPE_BUFFER, ArvBufferClass))
@@ -59,29 +88,13 @@ typedef enum {
 #define ARV_IS_BUFFER_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), ARV_TYPE_BUFFER))
 #define ARV_BUFFER_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS((obj), ARV_TYPE_BUFFER, ArvBufferClass))
 
+typedef struct _ArvBufferPrivate ArvBufferPrivate;
 typedef struct _ArvBufferClass ArvBufferClass;
 
 struct _ArvBuffer {
 	GObject	object;
 
-	size_t size;
-	gboolean is_preallocated;
-	void *data;
-
-	void *user_data;
-	GDestroyNotify user_data_destroy_func;
-
-	ArvBufferStatus status;
-
-	guint32 frame_id;
-	guint64 timestamp_ns;
-
-	guint32 x_offset;
-	guint32 y_offset;
-	guint32 width;
-	guint32 height;
-
-	ArvPixelFormat pixel_format;
+	ArvBufferPrivate *priv;
 };
 
 struct _ArvBufferClass {
@@ -90,11 +103,25 @@ struct _ArvBufferClass {
 
 GType arv_buffer_get_type (void);
 
-ArvBuffer *	arv_buffer_new_allocate	(size_t size);
-ArvBuffer *	arv_buffer_new 		(size_t size, void *preallocated);
-ArvBuffer * 	arv_buffer_new_full	(size_t size, void *preallocated,
-					 void *user_data, GDestroyNotify user_data_destroy_func);
-const void *	arv_buffer_get_data	(ArvBuffer *buffer, size_t *size);
+ArvBuffer *		arv_buffer_new_allocate		(size_t size);
+ArvBuffer *		arv_buffer_new 			(size_t size, void *preallocated);
+ArvBuffer * 		arv_buffer_new_full		(size_t size, void *preallocated,
+						 	void *user_data, GDestroyNotify user_data_destroy_func);
+
+ArvBufferStatus		arv_buffer_get_status		(ArvBuffer *buffer);
+
+ArvBufferPayloadType	arv_buffer_get_payload_type	(ArvBuffer *buffer);
+guint64			arv_buffer_get_timestamp	(ArvBuffer *buffer);
+const void *		arv_buffer_get_data		(ArvBuffer *buffer, size_t *size);
+
+void			arv_buffer_get_image_region		(ArvBuffer *buffer, gint *x, gint *y, gint *width, gint *height);
+gint			arv_buffer_get_image_width		(ArvBuffer *buffer);
+gint			arv_buffer_get_image_height		(ArvBuffer *buffer);
+gint			arv_buffer_get_image_x			(ArvBuffer *buffer);
+gint			arv_buffer_get_image_y			(ArvBuffer *buffer);
+ArvPixelFormat		arv_buffer_get_image_pixel_format	(ArvBuffer *buffer);
+
+const void *		arv_buffer_get_chunk_data	(ArvBuffer *buffer, guint64 chunk_id, size_t *size);
 
 G_END_DECLS
 
