@@ -224,6 +224,30 @@ arv_device_get_genicam_xml (ArvDevice *device, size_t *size)
 	return ARV_DEVICE_GET_CLASS (device)->get_genicam_xml (device, size);
 }
 
+/**
+ * arv_device_create_chunk_parser:
+ * @device: a #ArvDevice
+ *
+ * Create a #ArvChunkParser object, to be used for chunk data extraction from #ArvBuffer.
+ *
+ * Returns: (transfer full): a new #ArvChunkParser object, NULL on error.
+ *
+ * Since: 0.4.0
+ **/
+
+ArvChunkParser *
+arv_device_create_chunk_parser (ArvDevice *device)
+{
+	const char *xml = NULL;
+	gsize size = 0;
+
+	g_return_val_if_fail (ARV_IS_DEVICE (device), NULL);
+
+	xml = arv_device_get_genicam_xml (device, &size);
+
+	return arv_chunk_parser_new (xml, size);
+}
+
 /**
  * arv_device_get_feature:
  * @device: a #ArvDevice
@@ -668,7 +692,7 @@ arv_device_class_init (ArvDeviceClass *device_class)
 	arv_device_signals[ARV_DEVICE_SIGNAL_CONTROL_LOST] =
 		g_signal_new ("control-lost",
 			      G_TYPE_FROM_CLASS (device_class),
-			      0,
+			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ArvDeviceClass, control_lost),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0, G_TYPE_NONE);
