@@ -30,7 +30,7 @@
  * objects.
  */
 
-#include <arvstream.h>
+#include <arvstreamprivate.h>
 #include <arvbuffer.h>
 #include <arvdebug.h>
 
@@ -390,7 +390,7 @@ arv_stream_class_init (ArvStreamClass *node_class)
 	arv_stream_signals[ARV_STREAM_SIGNAL_NEW_BUFFER] =
 		g_signal_new ("new-buffer",
 			      G_TYPE_FROM_CLASS (node_class),
-			      0,
+			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ArvStreamClass, new_buffer),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0, G_TYPE_NONE);
